       IDENTIFICATION DIVISION.
       PROGRAM-ID.    OBFCTLC1.
       AUTHOR.        SIMOTIME TECHNOLOGIES.
       ENVIRONMENT DIVISION.
       INPUT-OUTPUT SECTION.
       FILE-CONTROL.
           SELECT OBFCTL80-FILE  ASSIGN TO       OBFCTL80
                  ORGANIZATION  IS SEQUENTIAL
                  ACCESS MODE   IS SEQUENTIAL
                  FILE STATUS   IS OBFCTL80-STATUS.

      *****************************************************************
       DATA DIVISION.
       FILE SECTION.
       FD  OBFCTL80-FILE
           DATA RECORD    IS OBFCTL80-REC.
       01  OBFCTL80-REC.
           05  OBFCTL80-DATA-01 PIC X(80).

      *****************************************************************
       WORKING-STORAGE SECTION.
       01  SIM-TITLE.
           05  T1 pic X(11) value '* OBFCTLC1 '.
           05  T2 pic X(34) value 'Access Control File, RSEQ 80 Bytes'.
           05  T3 pic X(10) value ' v08.02.09'.
           05  T4 pic X(24) value ' http://www.simotime.com'.
       01  SIM-COPYRIGHT.
           05  C1 pic X(11) value '* OBFCTLC1 '.
           05  C2 pic X(20) value 'Copyright 1987-2019 '.
           05  C3 pic X(28) value '   SimoTime Technologies    '.
           05  C4 pic X(20) value ' All Rights Reserved'.

       01  OBFCTL80-STATUS.
           05  OBFCTL80-STATUS-L     pic X.
           05  OBFCTL80-STATUS-R     pic X.
       01  OBFCTL80-EOF              pic X       value 'N'.
       01  OBFCTL80-OPEN-FLAG        pic X       value 'C'.

      *****************************************************************
      * The following buffers are used to create a four-byte status   *
      * code that may be displayed.                                   *
      *****************************************************************
       01  IO-STATUS.
           05  IO-STAT1            pic X.
           05  IO-STAT2            pic X.
       01  IO-STATUS-04.
           05  IO-STATUS-0401      pic 9     value 0.
           05  IO-STATUS-0403      pic 999   value 0.
       01  TWO-BYTES-BINARY        pic 9(4)  BINARY.
       01  TWO-BYTES-ALPHA         redefines TWO-BYTES-BINARY.
           05  TWO-BYTES-LEFT      pic X.
           05  TWO-BYTES-RIGHT     pic X.

      *****************************************************************
      * Message Buffer used by the Z-DISPLAY-MESSAGE-TEXT routine.    *
      *****************************************************************
       01  MESSAGE-BUFFER.
           05  MESSAGE-HEADER      pic X(11)   value '* OBFCTLC1 '.
           05  MESSAGE-TEXT.
               10  MESSAGE-TEXT-1  pic X(68)   value SPACES.
               10  MESSAGE-TEXT-2  pic X(188)  value SPACES.

      *****************************************************************
       01  APPL-RESULT             pic S9(9)   comp.
           88  APPL-AOK            value 0.
           88  APPL-EOF            value 16.

       01  WORK-04                 pic X(4)    value SPACES.
       01  FIRST-TIME              pic X       value 'Y'.

      *****************************************************************
       LINKAGE SECTION.
       COPY OBFCTLB1.

      *****************************************************************
       PROCEDURE DIVISION using OBFCTL-PASS-AREA.
           if  FIRST-TIME = 'Y'
               perform Z-POST-COPYRIGHT
               move 'N' to FIRST-TIME
           end-if
           move CTL-REQUEST to WORK-04
           evaluate WORK-04
             when 'READ' perform OBFCTL80-READ
                          if  OBFCTL80-STATUS = '00'
                              move OBFCTL80-REC to CTL-DATA
                              move ZEROES to CTL-RESPOND
                          else
                              move SPACES to CTL-DATA
                              perform Z-CONVERT-IO-STATUS
                              move IO-STATUS-04 to CTL-RESPOND
                          end-if
             when 'OPEN' perform OBFCTL80-OPEN-INPUT
             when 'EOJ ' perform OBFCTL80-CLOSE
             when 'HELP' perform Z-POST-COPYRIGHT
             when other  move '99' to OBFCTL80-STATUS
           end-evaluate
           GOBACK.

      *****************************************************************
      * I/O Routines for the Control File...                          *
      *****************************************************************
       OBFCTL80-CLOSE.
           add 8 to ZERO giving APPL-RESULT.
           close OBFCTL80-FILE
           if  OBFCTL80-STATUS = '00'
               subtract APPL-RESULT from APPL-RESULT
           else
               add 12 to ZERO giving APPL-RESULT
           end-if
           if  APPL-AOK
               CONTINUE
           else
               move 'CLOSE Failure with OBFCTL80' to MESSAGE-TEXT
               perform Z-DISPLAY-MESSAGE-TEXT
               move OBFCTL80-STATUS to IO-STATUS
               perform Z-DISPLAY-IO-STATUS
               perform Z-ABEND-PROGRAM
           end-if
           exit.
      *---------------------------------------------------------------*
       OBFCTL80-READ.
           read OBFCTL80-FILE
           if  OBFCTL80-STATUS = '00'
               subtract APPL-RESULT from APPL-RESULT
           else
               if  OBFCTL80-STATUS = '10'
                   add 16 to ZERO giving APPL-RESULT
               else
                   add 12 to ZERO giving APPL-RESULT
               end-if
           end-if
           if  APPL-AOK
               CONTINUE
           else
               if  APPL-EOF
                   move 'Y' to OBFCTL80-EOF
                   move OBFCTL80-STATUS to IO-STATUS
               else
                   move 'READ Failure with OBFCTL80' to MESSAGE-TEXT
                   perform Z-DISPLAY-MESSAGE-TEXT
                   move OBFCTL80-STATUS to IO-STATUS
                   perform Z-DISPLAY-IO-STATUS
                   perform Z-ABEND-PROGRAM
               end-if
           end-if
           exit.
      *---------------------------------------------------------------*
       OBFCTL80-OPEN-INPUT.
           add 8 to ZERO giving APPL-RESULT.
           open input OBFCTL80-FILE
           if  OBFCTL80-STATUS = '00'
               subtract APPL-RESULT from APPL-RESULT
               move 'O' to OBFCTL80-OPEN-FLAG
           else
               add 12 to ZERO giving APPL-RESULT
           end-if
           if  APPL-AOK
               CONTINUE
           else
               move 'OPEN Failure with OBFCTL80' to MESSAGE-TEXT
               perform Z-DISPLAY-MESSAGE-TEXT
               move OBFCTL80-STATUS to IO-STATUS
               perform Z-DISPLAY-IO-STATUS
               perform Z-ABEND-PROGRAM
           end-if
           exit.

      *****************************************************************
      * The following Z-ROUTINES provide administrative functions     *
      * for this program.                                             *
      *****************************************************************
      * ABEND the program, post a message to the console and issue    *
      * a STOP RUN.                                                   *
      *****************************************************************
       Z-ABEND-PROGRAM.
           if  MESSAGE-TEXT not = SPACES
               perform Z-DISPLAY-MESSAGE-TEXT
           end-if
           move 'PROGRAM-IS-ABENDING...'  to MESSAGE-TEXT
           perform Z-DISPLAY-MESSAGE-TEXT
           move IO-STATUS-04 to CTL-RESPOND
           add 12 to ZERO giving RETURN-CODE
      *    GOBACK.
           exit.

      *****************************************************************
      * Display CONSOLE messages...                                   *
      *****************************************************************
       Z-DISPLAY-MESSAGE-TEXT.
           if MESSAGE-TEXT-2 = SPACES
               display MESSAGE-BUFFER(1:79)
           else
               display MESSAGE-BUFFER
           end-if
           move all SPACES to MESSAGE-TEXT
           exit.

      *****************************************************************
      * Display the file status bytes. This routine will display as   *
      * four digits. If the full two byte file status is numeric it   *
      * will display as 00nn. If the 1st byte is a numeric nine (9)   *
      * the second byte will be treated as a binary number and will   *
      * display as 9nnn.                                              *
      *****************************************************************
       Z-DISPLAY-IO-STATUS.
           perform Z-CONVERT-IO-STATUS
           move 'File Status is: nnnn' to MESSAGE-TEXT
           move IO-STATUS-04 to MESSAGE-TEXT(17:4)
           perform Z-DISPLAY-MESSAGE-TEXT
           exit.
       Z-CONVERT-IO-STATUS.
           if  IO-STATUS not NUMERIC
           or  IO-STAT1 = '9'
               move IO-STAT1 to IO-STATUS-04(1:1)
               subtract TWO-BYTES-BINARY from TWO-BYTES-BINARY
               move IO-STAT2 to TWO-BYTES-RIGHT
               add TWO-BYTES-BINARY to ZERO giving IO-STATUS-0403
           else
               move '0000' to IO-STATUS-04
               move IO-STATUS to IO-STATUS-04(3:2)
           end-if
           exit.

      *****************************************************************
       Z-POST-COPYRIGHT.
           display SIM-TITLE     upon console
           display SIM-COPYRIGHT upon console
           exit.
      *****************************************************************
      *             A product of SimoTime Technologies                *
      *        Our e-mail address is: helpdesk@simotime.com           *
      *     Also, visit our Web Site at http://www.simotime.com       *
      *****************************************************************
