@echo OFF
     set CmdName=OBFCTLE2
rem  * *******************************************************************
rem  *             Batch Job Script - a Windows Command File             *
rem  *         This program is provided by SimoTime Technologies         *
rem  *           (C) Copyright 1987-2019 All Rights Reserved             *
rem  *             Web Site URL:   http://www.simotime.com               *
rem  *                   e-mail:   helpdesk@simotime.com                 *
rem  * *******************************************************************
rem  *
rem  * Text   - Create various sequential files with 80-byte records.
rem  * Author - SimoTime Technologies
rem  * Date   - January 24, 1996
rem  *
rem  * This Job Script uses the Microsoft "ECHO" command to pipe instream
rem  * data to an ASCII/Text file. The following terms are used.
rem  *
rem  * LSEQ - a Line Sequential File or ASCII/Text File
rem  * RSEQ - a Record Sequential File. This example uses a file of
rem  *        80-byte records that may be ASCII or EBCDIC encoded.
rem  *
rem  * Once the LSEQ file is created it is used as input to create an
rem  * RSEQ file of 80-byte, ASCII-encoded records.
rem  *
rem  * Next, the LSEQ file is read a second time. The record content is
rem  * converted from ASCII to EBCDIC. A new RSEQ file is created with
rem  * the EBCDIC-encoded records.
rem  *
rem  * *******************************************************************
rem  * Step 1, Delete any previously created file...
rem  *
     call ..\ENV1BASE
rem  *
     call SimoNOTE "*******************************************************%CmdName% "
     call SimoNOTE "Starting JobName %CmdName%"
rem  * *-----------------------------------------------------------------*
     call SimoNOTE "Job_Step 1 of 5, Preparing the System and Job Environments"
     set RecordCount=25000
     set JobStatus=0
     set SYSOUT=%BASELIB1%\LOGS\SYSOUT_%CmdName%.txt
     set LSEQ0080=%BASECAT%\Txt1\SIMOTIME.TEXT.OBFCTL80.TXT
     if exist %LSEQ0080% del %LSEQ0080%
     call SIMONOTE "Generate the Control Files that define a record count of %RecordCount% "
rem  * *-----------------------------------------------------------------*
     call SimoNOTE "Job_Step 2 of 5, Create a Control File, ASC_LSEQ Format"
rem  *
rem  * Step 2, Create a new output file. Use the "echo" command provided
rem  *         with Microsoft Windows to pipe instream data to a new
rem  *         ASCII/Text file.
rem  *
rem  ....:....1....:....2....:....3....:....4....:....5....:....6....:....7....:....8
echo * A comment is identified by an asterisk (*) in position one (1)>%LSEQ0080%
echo * ..:....1....:....2....:....3....:....4....:....5....:....6....>>%LSEQ0080%
echo /CTL FLAGS=FFFF0100         >>%LSEQ0080%
echo /CTL RECORDS=%RecordCount%  >>%LSEQ0080%
rem  *
     if not exist %LSEQ0080% set JobStatus=20
     if not "%JobStatus%" == "0" goto EojTAG
     call SimoNOTE "Produced DataSet %LSEQ0080%"
rem  *
rem  * *-----------------------------------------------------------------*
     call SimoNOTE "Job_Step 3 of 5, Create a Control File, ASC_RSEQ Format"
rem  *
rem  * *******************************************************************
rem  * Step 3, Read the previously created Line Sequential File (LSEQ)
rem  *         and write a Record Sequential File (RSEQ) with 80-byte,
rem  *         ASCII-encoded records.
rem  *
     set GETLS080=%LSEQ0080%
     set PUTRS080=%BASECAT%\Asc1\SIMOTIME.DATA.OBFCTL80.DAT
     if exist %PUTRS080% del %PUTRS080%
     run CV80ALAR
     if not exist %PUTRS080% set JobStatus=30
     if not "%JobStatus%" == "0" goto EojTAG
     call SimoNOTE "Produced DataSet %PUTRS080%"
rem  *
rem  * *-----------------------------------------------------------------*
     call SimoNOTE "Job_Step 4 of 5, Create a Control File, EBC_RSEQ Format"
rem  *
rem  * *******************************************************************
rem  * Step 4, Read the previously created Line Sequential File (LSEQ)
rem  *         and write a Record Sequential File (RSEQ) with 80-byte,
rem  *         EBCDIC-encoded records.
rem  *
     set GETLS080=%LSEQ0080%
     set PUTRS080=%BASECAT%\Ebc1\SIMOTIME.DATA.OBFCTL80.DAT
     if exist %PUTRS080% del %PUTRS080%
     run CV80ALER
     if not exist %PUTRS080% set JobStatus=40
     if not "%JobStatus%" == "0" goto EojTAG
     call SimoNOTE "Produced DataSet %PUTRS080%"
:EojTAG
rem  * *-----------------------------------------------------------------*
     call SimoNOTE "Job_Step 5 of 5, End of Job processing"
     if "%JobStatus%" == "0" goto :EojAOK
     goto :EojNOK
rem  *
:EojAOK
     call SimoNOTE "Finished JobName %CmdName%, Job Status is %JobStatus% "
     goto :End
:EojNOK
     call SimoNOTE "ABENDING JobName %CmdName%, Job Status is %JobStatus% "
rem  *
:End
     call SimoNOTE "Conclude SYSOUT is %SYSOUT%"
     if not "%1" == "nopause" pause
