       IDENTIFICATION DIVISION.
       PROGRAM-ID.    OBFDATC2.
       AUTHOR.        SIMOTIME TECHNOLOGIES.
      *****************************************************************
      * Copyright (C) 1987-2020 SimoTime Technologies.                *
      *                                                               *
      * All rights reserved.  Unpublished, all rights reserved under  *
      * copyright law and international treaty.  Use of a copyright   *
      * notice is precautionary only and does not imply publication   *
      * or disclosure.                                                *
      *                                                               *
      * Permission to use, copy, modify and distribute this software  *
      * for any commercial purpose requires a fee to be paid to       *
      * SimoTime Technologies. Once the fee is received by SimoTime   *
      * the latest version of the software will be delivered and a    *
      * license will be granted for use within an enterprise,         *
      * provided the SimoTime copyright notice appear on all copies   *
      * of the software. The SimoTime name or Logo may not be used    *
      * in any advertising or publicity pertaining to the use of the  *
      * software without the written permission of SimoTime           *
      * Technologies.                                                 *
      *                                                               *
      * Permission to use, copy and modify this software for any      *
      * non-commercial purpose and without fee is hereby granted,     *
      * provided the SimoTime copyright notice appear on all copies   *
      * of the software. The SimoTime name or Logo may not be used in *
      * any advertising or publicity pertaining to the use of the     *
      * software without the written permission of SimoTime           *
      * Technologies.                                                 *
      *                                                               *
      * SimoTime Technologies makes no warranty or representations    *
      * about the suitability of the software for any purpose. It is  *
      * provided "AS IS" without any expressed or implied warranty,   *
      * including the implied warranties of merchantability, fitness  *
      * for a particular purpose and non-infringement. SimoTime       *
      * Technologies shall not be liable for any direct, indirect,    *
      * special or consequential damages resulting from the loss of   *
      * use, data or projects, whether in an action of contract or    *
      * tort, arising out of or in connection with the use or         *
      * performance of this software                                  *
      *                                                               *
      * SimoTime Technologies                                         *
      * 15 Carnoustie Drive                                           *
      * Novato, CA 94949-5849                                         *
      * 415.883.6565                                                  *
      *                                                               *
      * RESTRICTED RIGHTS LEGEND                                      *
      * Use, duplication, or disclosure by the Government is subject  *
      * to restrictions as set forth in subparagraph (c)(1)(ii) of    *
      * the Rights in Technical Data and Computer Software clause at  *
      * DFARS 52.227-7013 or subparagraphs (c)(1) and (2) of          *
      * Commercial  Computer Software - Restricted Rights  at 48      *
      * CFR 52.227-19, as applicable.  Contact SimoTime Technologies, *
      * 15 Carnoustie Drive, Novato, CA 94949-5849.                   *
      *                                                               *
      *****************************************************************
      *      This program is provided by SimoTime Technologies        *
      *        Our e-mail address is: helpdesk@simotime.com           *
      *     Also, visit our Web Site at http://www.simotime.com       *
      *                                                               *
      *****************************************************************
      *
      *****************************************************************
      * Source Member: OBFDATC2.CBL
      * Copy Files:    QQSMREC1.CPY
      *****************************************************************
      *
      * OBFDATC2 - Execute OBFDATC2 to read a QSAM file and  update
      * a VSAM Keyed Sequential Data Set (KSDS).
      *
      * EXECUTION or CALLING PROTOCOL
      * -----------------------------
      * Use standard JCL to EXECUTE or ANIMATE.
      *
      * DESCRIPTION
      * -----------
      * This single COBOL program will read an 80-byte, EBCDIC, QSAM
      * file an populate or update an empty or existing KSDS, VSAM
      * data set.
      *
      *    ************
      *    * KSDUPD *
      *    ********jcl*
      *         *
      *         *
      *    ************     ************
      *    * OBFDATC2 *-----* OBF1CUST *
      *    ********cbl*     *******vsam*
      *         *
      *         *
      *    ************
      *    *   EOJ    *
      *    ************
      *
      *****************************************************************
      *
      * MAINTENANCE
      * -----------
      * 1997/02/27 Simmons, Created program.
      * 1997/02/27 Simmons, No changes to date.
      *
      *****************************************************************
       ENVIRONMENT DIVISION.
       INPUT-OUTPUT   SECTION.
       FILE-CONTROL.
      *****************************************************************
           SELECT OBF1CUST-FILE
               ASSIGN       to OBF1CUST
               ORGANIZATION is indexed
               ACCESS MODE  is SEQUENTIAL
               RECORD KEY   is CUST-NUMBER
               FILE STATUS  is OBF1CUST-STATUS.

      *****************************************************************
       DATA DIVISION.
       FILE SECTION.
       FD  OBF1CUST-FILE.
       COPY CUSTCB01.

      *****************************************************************
       WORKING-STORAGE SECTION.
      *****************************************************************
      *    Data-structure for Title and Copyright...
      *****************************************************************
       01  SIM-TITLE.
           05  T1 pic X(11) value '* OBFDATC2 '.
           05  T2 pic X(34) value 'Sequential Load of an Empty KSDS  '.
           05  T3 pic X(10) value ' v20.00.00'.
           05  T4 pic X(24) value ' http://www.simotime.com'.
       01  SIM-COPYRIGHT.
           05  C1 pic X(11) value '* OBFDATC2 '.
           05  C2 pic X(20) value 'Copyright 1987-2020 '.
           05  C3 pic X(28) value '   SimoTime Technologies    '.
           05  C4 pic X(20) value ' All Rights Reserved'.

       01  SIM-THANKS-01.
           05  C1 pic X(11) value '* OBFDATC2 '.
           05  C2 pic X(32) value 'Thank you for using this program'.
           05  C3 pic X(32) value ' provided from SimoTime Technolo'.
           05  C4 pic X(04) value 'gies'.

       01  SIM-THANKS-02.
           05  C1 pic X(11) value '* OBFDATC2 '.
           05  C2 pic X(32) value 'Please send all inquires or sugg'.
           05  C3 pic X(32) value 'estions to the helpdesk@simotime'.
           05  C4 pic X(04) value '.com'.

       01  OBF1CUST-STATUS.
           05  OBF1CUST-STAT1      pic X.
           05  OBF1CUST-STAT2      pic X.

      *****************************************************************
      * The following buffers are used to create a four-byte status   *
      * code that may be displayed.                                   *
      *****************************************************************
       01  IO-STATUS.
           05  IO-STAT1            pic X.
           05  IO-STAT2            pic X.
       01  IO-STATUS-04.
           05  IO-STATUS-0401      pic 9     value 0.
           05  IO-STATUS-0403      pic 999   value 0.
       01  TWO-BYTES-BINARY        pic 9(4)  BINARY.
       01  TWO-BYTES-ALPHA         redefines TWO-BYTES-BINARY.
           05  TWO-BYTES-LEFT      pic X.
           05  TWO-BYTES-RIGHT     pic X.

       01  END-OF-FILE             pic X(3)    value 'NO '.

      *****************************************************************
      *    Buffer used for posting messages to the console.
      *****************************************************************
       01  MESSAGE-BUFFER.
           05  MESSAGE-HEADER      pic X(11)   value '* OBFDATC2 '.
           05  MESSAGE-TEXT.
               10  MESSAGE-TEXT-1  pic X(68)   value SPACES.
               10  MESSAGE-TEXT-2  pic X(188)  value SPACES.
       01  MSG-LSB                 pic 9(3)    value 267.

       01  WORK-DATE.
           05  WORK-DATE-CC        pic X(02).
           05  WORK-DATE-YY        pic 9(02).
           05  WORK-DATE-MM        pic X(02).
           05  WORK-DATE-DD        pic 9(02).
       01  WORK-TIME.
           05  WORK-TIME-HH        pic X(02).
           05  WORK-TIME-NN        pic X(02).
           05  WORK-TIME-SS        pic X(02).
           05  WORK-TIME-TT        pic X(02).

       01  APPL-RESULT             pic S9(9)   comp.
           88  APPL-AOK            value 0.
           88  APPL-EOF            value 16.

       01  IDX-1                   pic 9(3)    value 1.
       01  IDX-2                   pic 9(3)    value 1.
       01  PTR-2                   pic 9(3)    value 1.

       01  WORK-05                 pic X(5)   value SPACES.
       01  WORK-09-A.
           05  WORK-09-N           pic 9(9)   value 0.
       01  Z-X9                    pic 9(2)   value 0.

       01  LOWER-CASE  pic X(26)   value 'abcdefghijklmnopqrstuvwxyz'.
       01  UPPER-CASE  pic X(26)   value 'ABCDEFGHIJKLMNOPQRSTUVWXYZ'.

       01  DUMB-KEY.
           05  DUMB-FIRST-BYTE     pic X       value '0'.
           05  DUMB-COUNT-11       pic 9(11)   value 0.

       01  PACING-COUNT            pic 9(9)    value 100000.
       01  PACING-COUNT-02         pic 9(9)    value 0.

       01  TOTAL-UPDATES.
           05  FILLER                pic X(13) value 'Record Count='.
           05  UPD-COUNT             pic 9(9)  value 0.
           05  FILLER pic XX    value ', '.
           05  FILLER pic X(30) value 'to Update Existing Entries    '.
           05  FILLER pic XX    value ' *'.

       01  TOTAL-ADDS.
           05  FILLER                pic X(13) value 'Record Count='.
           05  ADD-COUNT             pic 9(9)  value 0.
           05  FILLER pic XX    value ', '.
           05  FILLER pic X(30) value 'for Adding of New Entries     '.
           05  FILLER pic XX    value ' *'.

       01  TARGET-STMT-01.
           05  FILLER                pic X(13) value 'Record Count='.
           05  TARGET-RECORD-COUNT   pic 9(9)    value 100000.
           05  FILLER pic XX    value ', '.
           05  FILLER pic X(30) value 'User defined Number of Entries'.
           05  FILLER pic XX    value ' *'.

       01  ACTUAL-STMT-01.
           05  FILLER                pic X(13) value 'Record Count='.
           05  ACTUAL-RECORD-COUNT   pic 9(9)  value 0.
           05  ACTUAL-RECORD-ALPHA   redefines ACTUAL-RECORD-COUNT
                                     pic X(9).
           05  FILLER pic XX    value ', '.
           05  FILLER pic X(30) value '&&:&&:&&:&& - Interim         '.
           05  FILLER pic XX    value ' *'.

       COPY OBFCTLB1.
       COPY PASSOBB1.

      *****************************************************************
       PROCEDURE DIVISION.
           perform Z-POST-COPYRIGHT.
           perform ACTION-OR-BEHAVIOR
           perform Z-GET-DATE-AND-TIME

           move TARGET-STMT-01 to MESSAGE-TEXT
           perform Z-POST-MESSAGE-TO-USER

           perform OBF1CUST-OPEN

           move 'G' to OBB1-REQUEST

           perform until ACTUAL-RECORD-COUNT = TARGET-RECORD-COUNT
                      or ACTUAL-RECORD-COUNT > TARGET-RECORD-COUNT
             if  ACTUAL-RECORD-COUNT = PACING-COUNT-02
             or  ACTUAL-RECORD-COUNT > PACING-COUNT-02
                 perform POST-USER-MESSAGE
                 add PACING-COUNT to PACING-COUNT-02
             end-if
             perform INITIALIZE-CUSTOMER-RECORD
             add 1 to DUMB-COUNT-11
             move DUMB-KEY to CUST-NUMBER
             call 'OBFDATR1' using OBB1-PASS-AREA
             perform BUILD-CUSTOMER-RECORD
             perform OBF1CUST-WRITE
             add 1 to ADD-COUNT
             add 1 to ACTUAL-RECORD-COUNT
           end-perform
           perform POST-USER-MESSAGE

           perform OBF1CUST-CLOSE.

           move 'C' to OBB1-REQUEST
           call 'OBFDATR1' using OBB1-PASS-AREA

           move TOTAL-ADDS to MESSAGE-TEXT
           perform Z-POST-MESSAGE-TO-USER
           move TOTAL-UPDATES to MESSAGE-TEXT
           perform Z-POST-MESSAGE-TO-USER

           if  ACTUAL-RECORD-COUNT = TARGET-RECORD-COUNT
           or  ACTUAL-RECORD-COUNT > TARGET-RECORD-COUNT
               move ZERO to RETURN-CODE
           else
               add 16 to ZERO giving RETURN-CODE
           end-if

           perform Z-THANK-YOU.

           GOBACK.

      *****************************************************************
       ACTION-OR-BEHAVIOR.
           move 'GGGG1000' to OBB1-BEHAVIOR-FLAGS
           move 'OUTPUT'   to OBB1-OPEN-MODE
           move '0000' to CTL-RESPOND
           move 'OPEN' to CTL-REQUEST
           call 'OBFCTLC1' using OBFCTL-PASS-AREA

           move 'READ' to CTL-REQUEST
           perform until CTL-RESPOND not = '0000'
           call 'OBFCTLC1' using OBFCTL-PASS-AREA
               if  CTL-RESPOND = '0000'
                   move CTL-DATA(1:5) to WORK-05
                   inspect WORK-05 converting LOWER-CASE to UPPER-CASE
                   if  WORK-05 = '/CTL '
                       inspect CTL-DATA
                       converting LOWER-CASE to UPPER-CASE
                       if  CTL-DATA(6:8) = 'RECORDS='
                           move CTL-DATA(14:9)
                             to WORK-09-A
                           perform RIGHT-ADJUST-09
                           add WORK-09-N to ZERO
                               giving TARGET-RECORD-COUNT
                       end-if
                       if  CTL-DATA(6:7) = 'PACING='
                           move CTL-DATA(13:9)
                             to WORK-09-A
                           perform RIGHT-ADJUST-09
                           if WORK-09-N < 1000
                              add 1000      to ZERO giving PACING-COUNT
                           else
                              add WORK-09-N to ZERO giving PACING-COUNT
                           end-if
                       end-if
                       if  CTL-DATA(6:6) = 'FLAGS='
                           move CTL-DATA(12:8)
                             to OBB1-BEHAVIOR-FLAGS
                       end-if
                       if  CTL-DATA(6:5) = 'OPEN='
                       and OBB1-BF-06 = '1'
                           evaluate CTL-DATA(11:6)
                             when 'I-O   ' move CTL-DATA(11:6)
                                             to OBB1-OPEN-MODE
                             when 'OUTPUT' move CTL-DATA(11:6)
                                             to OBB1-OPEN-MODE
                             when OTHER    move 'OUTPUT'
                                             to OBB1-OPEN-MODE
                             end-evaluate
                       end-if
                   end-if
                   display CTL-DATA  upon console
               end-if
           end-perform

           if  CTL-RESPOND = '0010'
               move 'EOJ ' to CTL-REQUEST
               call 'OBFCTLC1' using OBFCTL-PASS-AREA
           end-if
           exit.

      *****************************************************************
       POST-USER-MESSAGE.
           perform Z-GET-DATE-AND-TIME
           move ACTUAL-STMT-01 to MESSAGE-TEXT
           inspect MESSAGE-TEXT replacing first '&&'
                                             by  WORK-TIME-HH
           inspect MESSAGE-TEXT replacing first '&&'
                                             by  WORK-TIME-NN
           inspect MESSAGE-TEXT replacing first '&&'
                                             by  WORK-TIME-SS
           inspect MESSAGE-TEXT replacing first '&&'
                                             by  WORK-TIME-TT
           perform Z-POST-MESSAGE-TO-USER
           exit.

      *****************************************************************
       RIGHT-ADJUST-09.
           perform until WORK-09-A(9:1) not = SPACE
               if  WORK-09-A(9:1) = SPACE
                   add 8 to ZERO giving Z-X9
                   perform 8 times
                     move WORK-09-A(Z-X9:1) to WORK-09-A(Z-X9 + 1:1)
                     subtract 1 from Z-X9
                   end-perform
                   move ZERO to WORK-09-A(1:1)
               end-if
           end-perform
           exit.

      *****************************************************************
       BUILD-CUSTOMER-RECORD.
           move OBB1-LAST-NAME   to CUST-LAST-NAME
           move OBB1-FIRST-NAME  to CUST-FIRST-NAME
           move OBB1-MID-NAME    to CUST-MID-NAME
           move OBB1-ADDRESS-1   to CUST-ADDRESS-1
           move OBB1-ADDRESS-2   to CUST-ADDRESS-2
           move OBB1-CITY        to CUST-CITY
           move OBB1-STATE       to CUST-STATE
           move OBB1-POSTAL-CODE to CUST-POSTAL-CODE
           perform BUILD-CUSTOMER-RECORD-01
           exit.

      *****************************************************************
       BUILD-CUSTOMER-RECORD-01.
           move WORK-DATE to CUST-LADATE
           move WORK-TIME to CUST-LATIME
           move ZERO to CUST-TOKEN
           exit.

      *****************************************************************
       INITIALIZE-CUSTOMER-RECORD.
           move all SPACES to CUST-RECORD
           initialize CUST-RECORD
           exit.

      *****************************************************************
      * Routines to do a read by KEY of the KSDS, VSAM Data Set. If   *
      * the read is successful then the record may be updated else a  *
      * new record may be added.                                      *
      *****************************************************************
       OBF1CUST-GET.
           read OBF1CUST-FILE
           if  OBF1CUST-STATUS = '00'
               subtract APPL-RESULT from APPL-RESULT
           else
               if  OBF1CUST-STATUS = '10'
                   add 16 to ZERO giving APPL-RESULT
               else
                   add 12 to ZERO giving APPL-RESULT
               end-if
           end-if
           if  APPL-AOK
               CONTINUE
           else
               if  APPL-EOF
                   move 'YES' to END-OF-FILE
               end-if
           end-if
           exit.
      *---------------------------------------------------------------*
       OBF1CUST-WRITE.
           write CUST-RECORD
           if  OBF1CUST-STATUS = '00'
               subtract APPL-RESULT from APPL-RESULT
           else
               if  OBF1CUST-STATUS = '10'
                   add 16 to ZERO giving APPL-RESULT
               else
                   add 12 to ZERO giving APPL-RESULT
               end-if
           end-if
           if  APPL-AOK
               CONTINUE
           else
               if  APPL-EOF
                   move 'YES' to END-OF-FILE
               else
                   move 'OBFDATC2 OBF1CUST-FAILURE-WRITE...'
                     to   MESSAGE-TEXT
                   move OBF1CUST-STATUS to IO-STATUS
                   perform Z-POST-MESSAGE-TO-USER
                   perform Z-DISPLAY-IO-STATUS
                   perform Z-ABEND-PROGRAM
               end-if
           end-if
           exit.
      *---------------------------------------------------------------*
       OBF1CUST-REWRITE.
           REWRITE CUST-RECORD
           if  OBF1CUST-STATUS = '00'
               subtract APPL-RESULT from APPL-RESULT
           else
               if  OBF1CUST-STATUS = '10'
                   add 16 to ZERO giving APPL-RESULT
               else
                   add 12 to ZERO giving APPL-RESULT
               end-if
           end-if
           if  APPL-AOK
               CONTINUE
           else
               if  APPL-EOF
                   move 'YES' to END-OF-FILE
               else
                   move 'OBFDATC2 OBF1CUST-FAILURE-REWRITE...'
                     to   MESSAGE-TEXT
                   move OBF1CUST-STATUS to IO-STATUS
                   perform Z-POST-MESSAGE-TO-USER
                   perform Z-DISPLAY-IO-STATUS
                   perform Z-ABEND-PROGRAM
               end-if
           end-if
           exit.
      *---------------------------------------------------------------*
       OBF1CUST-OPEN.
           add 8 to ZERO giving APPL-RESULT.
           open OUTPUT OBF1CUST-FILE
           if  OBF1CUST-STATUS = '35'
               move 'OBFDATC2 OBF1CUST-ATTEMPT-OPEN-OUTPUT...'
                 to MESSAGE-TEXT
               perform Z-POST-MESSAGE-TO-USER
               move OBF1CUST-STATUS to IO-STATUS
               perform Z-DISPLAY-IO-STATUS
           end-if
           if  OBF1CUST-STATUS = '00'
               subtract APPL-RESULT from APPL-RESULT
           else
               add 12 to ZERO giving APPL-RESULT
           end-if
           if  APPL-AOK
               CONTINUE
           else
               move 'OBFDATC2 OBF1CUST-FAILURE-OPEN...'
                 to MESSAGE-TEXT
               move OBF1CUST-STATUS to IO-STATUS
               perform Z-POST-MESSAGE-TO-USER
               perform Z-DISPLAY-IO-STATUS
               perform Z-ABEND-PROGRAM
           end-if
           exit.
      *---------------------------------------------------------------*
       OBF1CUST-CLOSE.
           add 8 to ZERO giving APPL-RESULT.
           close OBF1CUST-FILE
           if  OBF1CUST-STATUS = '00'
               subtract APPL-RESULT from APPL-RESULT
           else
               add 12 to ZERO giving APPL-RESULT
           end-if
           if  APPL-AOK
               CONTINUE
           else
               move 'OBFDATC2 OBF1CUST-FAILURE-CLOSE...'
                 to   MESSAGE-TEXT
               move OBF1CUST-STATUS to IO-STATUS
               perform Z-POST-MESSAGE-TO-USER
               perform Z-DISPLAY-IO-STATUS
               perform Z-ABEND-PROGRAM
           end-if
           exit.

      *****************************************************************
      * The following Z-Routines perform administrative tasks         *
      * for this program.                                             *
      *****************************************************************
      *
      *****************************************************************
      * ABEND the program, post a message to the console and issue    *
      * a STOP RUN.                                                   *
      *****************************************************************
       Z-ABEND-PROGRAM.
           if  MESSAGE-TEXT not = SPACES
               perform Z-POST-MESSAGE-TO-USER
           end-if
           move 'OBFDATC2 PROGRAM-IS-ABENDING...'  to MESSAGE-TEXT
           perform Z-POST-MESSAGE-TO-USER
           add 12 to ZERO giving RETURN-CODE
           STOP RUN.
      *    exit.

      *****************************************************************
       Z-CALCULATE-MESSAGE-LSB.
           if  MESSAGE-TEXT-2 = SPACES
               add  79 to ZERO giving MSG-LSB
           else
               add 267 to ZERO giving MSG-LSB
           end-if
           perform until MSG-LSB < 80
                      or MESSAGE-BUFFER(MSG-LSB:1) not = SPACE
             if MESSAGE-BUFFER(MSG-LSB:1) = SPACE
                subtract 1 from MSG-LSB
             end-if
           end-perform
           exit.

      *****************************************************************
      * Display message to SYSOUT device...                           *
      *****************************************************************
       Z-POST-MESSAGE-TO-SYSOUT.
           perform Z-CALCULATE-MESSAGE-LSB
           display MESSAGE-BUFFER(1:MSG-LSB)
           move all SPACES to MESSAGE-TEXT
           exit.

      *****************************************************************
      * Display message to CONSOLE device...                          *
      *****************************************************************
       Z-POST-MESSAGE-TO-CONSOLE.
           perform Z-CALCULATE-MESSAGE-LSB
           display MESSAGE-BUFFER(1:MSG-LSB) upon console
           exit.

      *****************************************************************
       Z-POST-MESSAGE-TO-USER.
           perform Z-POST-MESSAGE-TO-CONSOLE
           perform Z-POST-MESSAGE-TO-SYSOUT
           exit.

      *****************************************************************
      * Display the file status bytes. This routine will display as   *
      * four digits. If the full two byte file status is numeric it   *
      * will display as 00nn. If the 1st byte is a numeric nine (9)   *
      * the second byte will be treated as a binary number and will   *
      * display as 9nnn.                                              *
      *****************************************************************
       Z-DISPLAY-IO-STATUS.
           if  IO-STATUS not NUMERIC
           or  IO-STAT1 = '9'
               move IO-STAT1 to IO-STATUS-04(1:1)
               subtract TWO-BYTES-BINARY from TWO-BYTES-BINARY
               move IO-STAT2 to TWO-BYTES-RIGHT
               add TWO-BYTES-BINARY to ZERO giving IO-STATUS-0403
               move 'File Status is: nnnn' to MESSAGE-TEXT
               move IO-STATUS-04 to MESSAGE-TEXT(17:4)
               perform Z-POST-MESSAGE-TO-USER
           else
               move '0000' to IO-STATUS-04
               move IO-STATUS to IO-STATUS-04(3:2)
               move 'File Status is: nnnn' to MESSAGE-TEXT
               move IO-STATUS-04 to MESSAGE-TEXT(17:4)
               perform Z-POST-MESSAGE-TO-USER
           end-if
           exit.

      *****************************************************************
       Z-GET-DATE-AND-TIME.
           accept WORK-DATE from DATE YYYYMMDD
           accept WORK-TIME from TIME
           exit.

      *****************************************************************
       Z-POST-COPYRIGHT.
           move SIM-TITLE to MESSAGE-BUFFER
           perform Z-POST-MESSAGE-TO-USER
           move SIM-COPYRIGHT to MESSAGE-BUFFER
           perform Z-POST-MESSAGE-TO-USER
           exit.

      *****************************************************************
       Z-THANK-YOU.
           move SIM-THANKS-01 to MESSAGE-BUFFER
           perform Z-POST-MESSAGE-TO-USER
           move SIM-THANKS-02 to MESSAGE-BUFFER
           perform Z-POST-MESSAGE-TO-USER
           exit.
      *****************************************************************
      *      This example is provided by SimoTime Technologies        *
      *        Our e-mail address is: helpdesk@simotime.com           *
      *     Also, visit our Web Site at http://www.simotime.com       *
      *****************************************************************
